import Popup from "@/components/popup"
import { ScrollView, View } from "@tarojs/components"
import { FC, useEffect, useState } from "react"
import styles from './index.module.scss'
import { formatDateTime} from "@/common/format";
import {toRgb} from '@/common/bluetooth/color/colorSpace'
import Taro from "@tarojs/taro";

type PropsType = {
  showModal: boolean
  onColor?:Function
}

const HistoryColor: FC<PropsType> = (props) => {
  

  const { onColor, showModal } = props
  const [show, setShow] = useState(false)
  

  useEffect(() => {
    setShow(showModal)
  }, [showModal])
  

  const closeEven = () => {
    setShow(false)
  }

  const [list, setList] = useState([
    {
      p_time: 0,
      lab: [],
      code: '',
      name: ''
    }
  ])

  //保留1位小数
  const noScale = (val, num = 1) => {
    return val?.toFixed(num)
  }
  //rgb转换字符串
  const labRoRgb = (val) => {
    const rgb = toRgb(val)
    return `rgb(${rgb[0]},${rgb[1]},${rgb[2]})`
  }

  const getInfo = (item) => {
    onColor && onColor(item)
  }

  

  return (
    <View className={styles.history_color}>
      <Popup title='历史取样记录 ( 最近30条 )' show={show} onClose={closeEven}>
        <ScrollView className={styles['selectList-scroll-color']} scrollY>
          <View className={styles.selectCon}>
            {!!list?.length ? (
              list.map((item, index) => {
                return (
                  <View key={item.p_time} className={styles.selectList} onClick={() => getInfo(item)}>
                    <View className={styles.rgbColor} style={{ background: labRoRgb(item.lab) }}></View>
                    <View className={styles.product_con}>
                      <View className={styles.product_name}>{item.code + ' ' + item.name}</View>
                      <View className={styles.date}>{formatDateTime(item.p_time)}</View>
                    </View>
                    <View className={styles.labColor}>
                      <View className={styles.labColor_btn}>+</View>
                      <View className={styles.labColor_con}>
                        <View className={styles.L}>L*：{noScale(item.lab[0])}</View>
                        <View className={styles.a}>a*：{noScale(item.lab[1])}</View>
                        <View className={styles.b}>b*：{noScale(item.lab[2])}</View>
                      </View>
                    </View>
                  </View>
                )
              })
            ) : (
              <View className='noData'>暂无数据</View>
            )}
          </View>
        </ScrollView>
      </Popup>
    </View>
  )
}
export default HistoryColor
