import { View, Text } from '@tarojs/components'
import React, { FC } from 'react'
import classnames from 'classnames'
import styles from './index.module.scss'
import { formatHashTag } from '@/common/format'
import dayjs from 'dayjs'

type PropsType = {
  item?: Record<string, any>
  key?: any
  index?: number
  onPreviewRgb?: Function
  onTakeColor?: Function
}

const ColorCard: FC<PropsType> = (params) => {
  const { item = {}, index, onTakeColor, onPreviewRgb, key } = params

  const truncation = (ev) => {
    if (ev) {
      ev += ''
      let index = ev.lastIndexOf('.')
      let suffix = ev.substr(index + 1)
      if (suffix.length > 2) {
        suffix = suffix.substr(0, 1)
        ev = ev.substr(0, index) + '.' + suffix
      }
      return ev
    } else {
      return 0
    }
  }

  const handleTakeColor = () => {
    onTakeColor && onTakeColor(index)
  }

  const handlePreviewRgb = () => {
    onPreviewRgb && onPreviewRgb()
  }

  return (
    <View className={classnames(styles['color-list'], { flash: item.moveBorder == 1 })} key={key}>
      <View className={classnames(styles.vertical, { 'move-vertical': item.moveBorder == 2 })}>
        <View></View>
      </View>
      <View className={classnames(styles.horizontal, { 'move-horizontal': item.moveBorder == 2 })}></View>
      <View
        onClick={handlePreviewRgb}
        className={styles['c-image']}
        style={{
          backgroundColor: `rgb(
            ${item.currnetRgb?.r},
            ${item.currnetRgb?.g},
            ${item.currnetRgb?.b}
        )`,
        }}>
        {!item.sampling && <Text>末取样</Text>}
      </View>
      <View className={styles['c-info']}>
        <View className={styles['c-i-title']}>{formatHashTag(item.product_code, item.product_name)}</View>
        <Text>{formatHashTag(item.product_color_code, item.product_color_name)}</Text>
        <View className={styles['c-i-date']}>{item.absorb_lab_time && dayjs(item.absorb_lab_time).format('YYYY-MM-DD HH:mm:ss')}</View>
      </View>
      <View className={styles['c-lab']}>
        <View className={classnames(styles['c-lab-button'], { again: item.sampling })} onClick={handleTakeColor}>
          {item.sampling ? '重新取样' : '取样'}
        </View>
        <View className={styles['c-lab-text']}>
          <View>L*: {truncation(item?.currentLab?.l)}</View>
          <View>a*: {truncation(item?.currentLab?.a)}</View>
          <View>b*: {truncation(item?.currentLab?.b)}</View>
        </View>
      </View>
    </View>
  )
}
export default ColorCard
